<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-jqueryui?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// J
	'jqueryui_description' => 'Deze plugin implementeert het extra bibliotheek jQuery UI in SPIP waardoor de creatie van dynamische grafische tabs, drag & drop, vooruitgang bars mogelijk wordt...
Kenmerken van deze bibliotheek bestaan uit drie categorieën:
-* {{Interacties}}. Zij kunnen zeer interessante eigenschappen aan HTML-elementen geven, zoals de mogelijkheid om ze te kunnen grijpen en verplaatsen met de muis (drag & drop), aanpassen als een venster, of nog geselecteerd te worden als pictogrammen op het bureau van uw OS.
-* {{Widgets}}. Het zijn objecten "klaar voor gebruik" die een hoog niveau van functionaliteit aanbieden, zoals bijvoorbeeld  datepicker die een kalender aanmaakt om het selecteren van een datum te toelaten.
-* {{De effecten}}. Ze verrijken  de effecten aangeboden door jQuery (FadeIn, slideUp ...). Dankzij jQuery UI is het bijvoorbeeld mogelijk om de CSS background-color met .animate() te animeren of nog overgangen tijdens addClass / removeClass toe te voegen ...',
	'jqueryui_slogan' => 'jQuery Animatie, effecten en widgets '
);

?>
